# Younger

This repository maintains all code related to using the Younger dataset and its related applications.

Go to the website "[Datasets - Yangs Cloud](https://datasets.yangs.cloud/)" for [Detailed Documentation]([./README.ZH.md](https://datasets.yangs.cloud/younger/)) of Younger's Applications.

Due to ongoing updates to this branch, the code may not match the initial version presented in the paper. Therefore, if you need the version that corresponds to what is mentioned in the paper, please switch to the `paper` [branch](https://github.com/YangsCloud/Younger/tree/paper) for reference.

## Datasets
Browse and download the datasets at [here](https://datasets.yangs.cloud/younger/dataset_series).

## Citation
If you need to use our code or dataset, please cite the following paper:

1. Yang, Z., Gao, W., Peng, L., Huang, Y., Tang, F., & Zhan, J. (2024). Younger: The First Dataset for Artificial Intelligence-Generated Neural Network Architecture. [arXiv](https://arxiv.org/abs/2406.15132)
```bibtex
@misc{yang2024youngerdatasetartificialintelligencegenerated,
      title={Younger: The First Dataset for Artificial Intelligence-Generated Neural Network Architecture}, 
      author={Zhengxin Yang and Wanling Gao and Luzhou Peng and Yunyou Huang and Fei Tang and Jianfeng Zhan},
      year={2024},
      eprint={2406.15132},
      archivePrefix={arXiv},
      primaryClass={cs.LG},
      url={https://arxiv.org/abs/2406.15132}, 
}
```
